@@ -57,7 +57,7 @@ public class Open extends TagData {
 	}
 
 	public Open( Page page, boolean act_f ) {
-		super( page.getFirstTagByType( "body" ), !act_f );
+		super( page.getBodyTag(), !act_f );
 		page_id = page.getUniqueKey();
 		base_z = page.getZindex();
 		CSSValuable[]	st = page.getPopupBackGround();
