@@ -196,34 +196,22 @@ public class RequestParameter implements Serializable {
 	 * @return true:同一リクエスト、false:異なるリクエスト。
 	 */
 	public boolean equals( Object o ) {
-		if ( !(o instanceof RequestParameter) )	return false;
-		RequestParameter	r = (RequestParameter)o;
-		if ( !uri.equals( r.uri ) )	return false;
-		HashMap<String,RequestItem>	ok = new HashMap<String,RequestItem>();
+		if ( o == null )	return false;
+		return o.hashCode() == hashCode();
+	}
+
+	public int hashCode() {
+		int	ret = uri.hashCode();
 		for ( String k : item_map.keySet() ) {
+			ret += k.hashCode();
 			RequestItem	my_item = item_map.get( k );
-			RequestItem	ot_item = r.item_map.get( k );
-			if ( !my_item.equals( ot_item ) )	return false;
-			ok.put( k, my_item );
-		}
-		for ( String k : r.item_map.keySet() ) {
-			if ( ok.get( k ) == null )	return false;
-		}
-		HashMap<String,String[]>	ok2 = new HashMap<String,String[]>();
-		for ( String k : header.keySet() ) {
-			String[]	my_head = header.get( k );
-			String[]	ot_head = r.header.get( k );
-			if ( ot_head == null )	return false;
-			if ( my_head.length != ot_head.length )	return false;
-			for ( int i = 0; i < my_head.length; i++ ) {
-				if ( !my_head[i].equals( ot_head[i] ) )	return false;
+			String[]	v = my_item.getAllValue();
+			if ( v == null )	continue;
+			for ( int i = 0; i < v.length; i++ ) {
+				ret += v[i].hashCode();
 			}
-			ok2.put( k, my_head );
 		}
-		for ( String k : r.header.keySet() ) {
-			if ( ok2.get( k ) == null )	return false;
-		}
-		return true;
+		return ret;
 	}
 
 	/**
