@@ -67,10 +67,24 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	private HashMap<PageID, RedirectData>	pending = new HashMap<PageID, RedirectData>();
 	private volatile int client;
 
+	private String getAdder( HttpServletRequest req ) {
+		String	addr = req.getRemoteAddr();
+		if ( addr == null )	return null;
+		String[]	bt = addr.split( "[\\.:]" );
+		if ( bt.length < 4 )	return addr;
+		StringBuilder	buf = new StringBuilder( bt[0] );
+		int	len = bt.length - 1;
+		for ( int i = 1; i < len; i++ ) {
+			buf = buf.append( "." );
+			buf = buf.append( bt[1] );
+		}
+		return buf.toString();
+	}
+
 	private int getClient( HttpServletRequest req ) {
 		String[]	data = new String[] {
 			req.getHeader( RequestParameter.UA_HEAD ),
-			req.getRemoteAddr()
+			getAdder( req )
 		};
 		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < data.length; i++ ) {
